**Example 1: 获取动作顺序**



Input: 

```
tccli faceid GetActionSequence --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "ActionSequence": "1,2",
        "RequestId": "f904f4cf-75db-4f8f-a5ec-dc4f942c7f7a"
    }
}
```

